## Privacy Notice
Last Updated: 16 December 2025

This Privacy notice explains what personal data is collected by the Open Targets Platform MCP server, for what purposes, how it is processed, and how we keep it secure.

**We do not collect, store, or process any personal data from our users.**

This means, we don't directly or through third-party services:
- collect your name, email address, or contact information
- track your browsing activity or behavior
- use cookies or similar tracking technologies
- collect your IP address or device information
- store any information about your visits to our website/service

**Changes to This Notice**
If our data practices change in the future, we will update this Privacy Notice and indicate the date of the latest revision at the top of this page.

**Contact Us**
If you have any questions about this Privacy Notice, please contact us at:
outreach@opentargets.org